==> matrix_sdk-0.19.0.tar.gz: lib/src/event/room/state/room_avatar_change_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/room/room_event.dart';
import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:meta/meta.dart';
import 'package:url/url.dart';

class RoomAvatarChangeEvent extends StateEvent {
  @override
  final RoomAvatarChange content;

  RoomAvatarChangeEvent(
      this.content, RoomEventArgs args)
      : super(args, stateKey: '');

  factory RoomAvatarChangeEvent.fromJson(RoomEventArgs args, dynamic json) {
    if (!hasStateKey(json)) {
      return null;
    }

    final url = json['content']['url'];

    // TODO: Handle avatar removals
    if (url == null) {
      return null;
    }

    return RoomAvatarChangeEvent(
      RoomAvatarChange(url: Url.parse(url)), args);
  }
}

class RoomAvatarChange extends StateEventContent {
  /// An `mxc` url pointing to the avatar.
  final Url url;

  RoomAvatarChange({@required this.url});

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'url': url?.toString()
    });
}

==> matrix_sdk-0.19.4.tar.gz: lib/src/event/room/state/room_avatar_change_event.dart <==
// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/event/room/room_event.dart';
import 'package:matrix_sdk/src/event/room/state/state_event.dart';
import 'package:meta/meta.dart';
import 'package:url/url.dart';

class RoomAvatarChangeEvent extends StateEvent {
  @override
  final RoomAvatarChange content;

  RoomAvatarChangeEvent(this.content, RoomEventArgs args)
      : super(args, stateKey: '');

  factory RoomAvatarChangeEvent.fromJson(RoomEventArgs args, dynamic json) {
    if (!hasStateKey(json)) {
      return null;
    }

    final url = json['content']['url'];

    // TODO: Handle avatar removals
    if (url == null) {
      return null;
    }

    return RoomAvatarChangeEvent(
      RoomAvatarChange(
        url: Url.parse(url),
      ),
      args,
    );
  }
}

class RoomAvatarChange extends StateEventContent {
  /// An `mxc` url pointing to the avatar.
  final Url url;

  RoomAvatarChange({@required this.url});

  @override
  Map<String, dynamic> toJson() => super.toJson()
    ..addAll({
      'url': url?.toString(),
    });
}
